This negative number can be -2 if no patch header has been found,
otherwise it is -1.

As parse_chunk() is called only by apply_patch() which already
returns -1 when an error happened, let's make it return -1 when
parse_chunk() returns -1.

Signed-off-by: Christian Couder <chrisc...@tuxfamily.org>
---
 builtin/apply.c | 19 +++++++++++--------
 1 file changed, 11 insertions(+), 8 deletions(-)

diff --git a/builtin/apply.c b/builtin/apply.c
index 825ffe9..e1d6c8b 100644
--- a/builtin/apply.c
+++ b/builtin/apply.c
@@ -2110,22 +2110,22 @@ static int use_patch(struct apply_state *state, struct 
patch *p)
        return !state->has_include;
 }
 
-
 /*
  * Read the patch text in "buffer" that extends for "size" bytes; stop
  * reading after seeing a single patch (i.e. changes to a single file).
  * Create fragments (i.e. patch hunks) and hang them to the given patch.
  * Return the number of bytes consumed, so that the caller can call us
  * again for the next patch.
  */
 static int parse_chunk(struct apply_state *state, char *buffer, unsigned long 
size, struct patch *patch)
 {
        int hdrsize, patchsize;
        int offset = find_header(state, buffer, size, &hdrsize, patch);
 
-       if (offset == -1)
-               exit(1);
-
        if (offset < 0)
                return offset;
 
@@ -2185,8 +2185,9 @@ static int parse_chunk(struct apply_state *state, char 
*buffer, unsigned long si
                 * empty to us here.
                 */
                if ((state->apply || state->check) &&
-                   (!patch->is_binary && !metadata_changes(patch)))
-                       die(_("patch with only garbage at line %d"), 
state->linenr);
+                   (!patch->is_binary && !metadata_changes(patch))) {
+                       return error(_("patch with only garbage at line %d"), 
state->linenr);
+               }
        }
 
        return offset + hdrsize + patchsize;
@@ -4566,6 +4567,8 @@ static int apply_patch(struct apply_state *state,
                nr = parse_chunk(state, buf.buf + offset, buf.len - offset, 
patch);
                if (nr < 0) {
                        free_patch(patch);
+                       if (nr == -1)
+                               return -1;
                        break;
                }
                if (state->apply_in_reverse)
@@ -2110,22 +2110,22 @@ static int use_patch(struct apply_state *state, struct 
  * reading after seeing a single patch (i.e. changes to a single file).
  * Create fragments (i.e. patch hunks) and hang them to the given patch.
- * Return the number of bytes consumed, so that the caller can call us
- * again for the next patch.
+ *
+ * Returns:
+ *   -1 on error,
+ *   -2 if no header was found,
+ *   the number of bytes consumed otherwise,
+ *     so that the caller can call us again for the next patch.
  */
 static int parse_chunk(struct apply_state *state, char *buffer, unsigned long 
-- 
2.8.1.300.g5fed0c0

--
To unsubscribe from this list: send the line "unsubscribe git" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to